@@ -24,7 +24,7 @@ TODOs:
 """
 
 __author__ = "Andy Buckley <andy.buckley@cern.ch"
-__version__ = "1.4.2"
+__version__ = "1.4.4"
 
 
 def _autotype(var):
@@ -206,11 +206,11 @@ def readSLHA(spcstr, ignorenobr=False):
             currentdecay = None
             blocks[blockname] = Block(blockname, q=qstr)
         elif line.upper().startswith("DECAY"):
-            match = re.match(r"DECAY\s+(\d+)\s+([\d\.E+-]+).*", line.upper())
+            match = re.match(r"DECAY\s+(-?\d+)\s+([\d\.E+-]+|NAN).*", line.upper())
             if not match:
                 continue
             pdgid = int(match.group(1))
-            width = float(match.group(2))
+            width = float(match.group(2)) if match.group(2) != "NAN" else None
             currentblock = "DECAY"
             currentdecay = pdgid
             decays[pdgid] = Particle(pdgid, width)
@@ -228,10 +228,10 @@ def readSLHA(spcstr, ignorenobr=False):
                     else:
                         blocks[currentblock].add_entry(items)
                 else:
-                    br = float(items[0])
+                    br = float(items[0]) if items[0].upper() != "NAN" else None
                     nda = int(items[1])
                     ids = map(int, items[2:])
-                    if br > 0.0 or not ignorenobr:
+                    if br > 0.0 or not ignorenobr: # br == None is < 0
                         decays[currentdecay].add_decay(br, nda, ids)
 
     ## Try to populate Particle masses from the MASS block
